@@ -1,6 +1,6 @@
 /*
  * ansilove.h
- * libansilove 1.2.5
+ * libansilove 1.2.8
  * https://www.ansilove.org
  *
  * Copyright (c) 2011-2020 Stefan Vogt, Brian Cassidy, and Frederic Cambus
@@ -17,22 +17,27 @@
 #include <stddef.h>
 #include <stdint.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #define ANSILOVE_EXTERN __attribute__((visibility("default")))
 
 /* Version number */
-#define ANSILOVE_VERSION "1.2.5"
+#define ANSILOVE_VERSION "1.2.8"
 
 #define ANSILOVE_VERSION_MAJOR		1
 #define ANSILOVE_VERSION_MINOR		2
-#define ANSILOVE_VERSION_PATCH		5
+#define ANSILOVE_VERSION_PATCH		8
 
 /* Error codes */
 #define ANSILOVE_INVALID_PARAM		1
 #define ANSILOVE_FORMAT_ERROR		2
 #define ANSILOVE_MEMORY_ERROR		3
-#define ANSILOVE_FILE_READ_ERROR	4
-#define ANSILOVE_FILE_WRITE_ERROR	5
-#define ANSILOVE_GD_ERROR		6
+#define ANSILOVE_RANGE_ERROR		4
+#define ANSILOVE_FILE_READ_ERROR	5
+#define ANSILOVE_FILE_WRITE_ERROR	6
+#define ANSILOVE_GD_ERROR		7
 
 /* PC Fonts */
 #define ANSILOVE_FONT_CP437		1	/* IBM PC 80x25 */
@@ -94,8 +99,8 @@ struct ansilove_options {
 
 ANSILOVE_EXTERN int	 ansilove_init(struct ansilove_ctx *, struct ansilove_options *);
 ANSILOVE_EXTERN char	*ansilove_error(struct ansilove_ctx *);
-ANSILOVE_EXTERN int	 ansilove_loadfile(struct ansilove_ctx *, char *);
-ANSILOVE_EXTERN int	 ansilove_savefile(struct ansilove_ctx *, char *);
+ANSILOVE_EXTERN int	 ansilove_loadfile(struct ansilove_ctx *, const char *);
+ANSILOVE_EXTERN int	 ansilove_savefile(struct ansilove_ctx *, const char *);
 ANSILOVE_EXTERN int	 ansilove_clean(struct ansilove_ctx *);
 
 ANSILOVE_EXTERN int	 ansilove_ansi(struct ansilove_ctx *, struct ansilove_options *);
@@ -106,4 +111,8 @@ ANSILOVE_EXTERN int	 ansilove_pcboard(struct ansilove_ctx *, struct ansilove_opt
 ANSILOVE_EXTERN int	 ansilove_tundra(struct ansilove_ctx *, struct ansilove_options *);
 ANSILOVE_EXTERN int	 ansilove_xbin(struct ansilove_ctx *, struct ansilove_options *);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* ANSILOVE_H */
